@@ -2,7 +2,7 @@ package Net::IPAM::IP;
 
 use strict;
 use warnings;
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 use Socket qw/:addrinfo AF_INET AF_INET6 AF_UNSPEC SOCK_RAW/;
 
@@ -43,34 +43,37 @@ Net::IPAM::IP - A library for reading, formatting, sorting and converting IP-add
 
 =head1 SYNOPSIS
 
-	use Net::IPAM::IP;
+  use Net::IPAM::IP;
 
-	# parse and normalize
-	$ip1 = Net::IPAM::IP->new('1.2.3.4') // die 'wrong format,';
-	$ip2 = Net::IPAM::IP->new('fe80::1') // die 'wrong format,';
+  # parse and normalize
+  $ip1 = Net::IPAM::IP->new('1.2.3.4') // die 'wrong format,';
+  $ip2 = Net::IPAM::IP->new('fe80::1') // die 'wrong format,';
 
-	$ip3 = $ip2->incr // die 'overflow,';
+  $ip3 = $ip2->incr // die 'overflow,';
 
-	say $ip1;    # 1.2.3.4
-	say $ip2;    # fe80::1
-	say $ip3;    # fe80::2
+  say $ip1;    # 1.2.3.4
+  say $ip2;    # fe80::1
+  say $ip3;    # fe80::2
 
-	say $ip1->cmp($ip2);    # -1
+  say $ip1->cmp($ip2);    # -1
 
-	say $ip2->expand;       # fe80:0000:0000:0000:0000:0000:0000:0001
-	say $ip2->reverse;      # 1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.e.f
+  say $ip2->expand;       # fe80:0000:0000:0000:0000:0000:0000:0001
+  say $ip2->reverse;      # 1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.e.f
 
-	$ip = Net::IPAM::IP->new_from_bytes(pack('C4', 192, 168, 0, 1));       # 192.168.0.1
-	$ip = Net::IPAM::IP->new_from_bytes(pack('N4', 0x20010db8, 0, 0, 1,)); # 2001:db8::1
+  $ip = Net::IPAM::IP->new_from_bytes(pack('C4', 192, 168, 0, 1));       # 192.168.0.1
+  $ip = Net::IPAM::IP->new_from_bytes(pack('N4', 0x20010db8, 0, 0, 1,)); # 2001:db8::1
+
+  @ips = Net::IPAM::IP->getaddrs('dns.google.');
+  say "@ips";  #  8.8.8.8 8.8.4.4 2001:4860:4860::8844 2001:4860:4860::8888
 
 =cut
 
-=head1 METHODS
-
-L<Net::IPAM::IP> implements the following methods:
+=head1 CONSTRUCTORS
 
 =head2 new
 
+  $ip = Net::IPAM::IP->new("::1");
+
 Parse the input string as IPv4/IPv6 address and returns the IP address object.
 
 IPv4-mapped-IPv6 addresses are normalized and sorted as IPv4 addresses.
@@ -156,6 +159,77 @@ sub new_from_bytes {
   croak 'illegal input,';
 }
 
+=head2 getaddrs($name, [$error_cb])
+
+Returns a list of ip objects for a given $name or undef if there is no RR record for $name.
+
+  my @ips = Net::IPAM::IP->getaddrs('dns.google.');
+  say "@ips";  #  8.8.8.8 8.8.4.4 2001:4860:4860::8844 2001:4860:4860::8888
+
+L</"getaddrs"> calls the L<Socket> functions C<< getaddrinfo() >> and C<< getnameinfo() >> under the hood.
+
+With no error callback L</getaddrs> just calls C<< warn() >> with underlying Socket errors.
+
+For granular error handling use your own error callback:
+
+  my $my_error_cb = sub {
+    my ( $error, $msg) = @_;
+    # check the $error and do what you want with error and message
+    ...
+  }
+
+  my @ips = Net::IPAM::IP->getaddrs( $name, $my_error_cb );
+
+or shut up the default error handler with:
+
+  my @ips = Net::IPAM::IP->getaddrs( $name, sub { } );
+
+ANNOTATION: This constructor could also be named C<< new_from_name >> but it behaves differently
+because it returns a B<list> of objects and supports an optional argument as error callback,
+reporting underlying Socket errors.
+
+=cut
+
+sub getaddrs {
+  my ( $class, $name, $error_cb ) = @_;
+  $error_cb //= sub { warn "@_" };
+
+  unless ( defined $name ) {
+    $error_cb->( 0, "missing argument" );
+    return;
+  }
+
+  my ( $err, @res ) = getaddrinfo( $name, "", { socktype => SOCK_RAW, family => AF_UNSPEC } );
+
+  if ($err) {
+
+    # no error, just no resolveable name
+    return if $err == EAI_NONAME;
+
+    $error_cb->( $err, "getaddrinfo($name)" );
+    return;
+  }
+
+  my @ips;
+
+  while ( my $ai = shift @res ) {
+    my ( $err, $ip ) = getnameinfo( $ai->{addr}, NI_NUMERICHOST, NIx_NOSERV );
+
+    if ($err) {
+      $error_cb->( $err, "getnameinfo($name)" );
+      return;
+    }
+
+    push @ips, $class->new($ip);
+  }
+
+  return @ips;
+}
+
+=head1 METHODS
+
+L<Net::IPAM::IP> implements the following methods:
+
 =head2 bytes
 
   $ip = Net::IPAM::IP->new('fe80::');
@@ -357,7 +431,7 @@ Returns the DNS name for the ip object or undef if there is no PTR RR.
 
 L</"getname"> calls the L<Socket> functions C<< getaddrinfo() >> and C<< getnameinfo() >> under the hood.
 
-With no error callback L</getname> just calls C<< warn() >> on error.
+With no error callback L</getname> just calls C<< warn() >> with underlying Socket errors.
 
 =head3 LIMITATION:
 
@@ -392,73 +466,6 @@ sub getname {
   return $name;
 }
 
-=head1 CLASS-METHODS
-
-L<Net::IPAM::IP> implements the following class methods:
-
-=head2 getaddrs($name, [$error_cb])
-
-Returns a list of objects for a given $name or undef if there is no B<A> or B<AAAA> RR record.
-
-  my @ips = Net::IPAM::IP->getaddrs('dns.google.');
-  say "@ips";  #  8.8.8.8 8.8.4.4 2001:4860:4860::8844 2001:4860:4860::8888
-
-L</"getaddrs"> calls the L<Socket> functions C<< getaddrinfo() >> and C<< getnameinfo() >> under the hood.
-
-With no error callback L</getaddrs> just calls C<< warn() >> on error.
-
-For granular error handling use your own error callback:
-
-  my $my_error_cb = sub {
-    my ( $error, $msg) = @_;
-    # check the $error and do what you want with error and message
-    ...
-  }
-
-  my @ips = Net::IPAM::IP->getaddrs( $name, $my_error_cb );
-
-or shut up the default error handler with:
-
-  my @ips = Net::IPAM::IP->getaddrs( $name, sub { } );
-
-=cut
-
-sub getaddrs {
-  my ( $class, $name, $error_cb ) = @_;
-  $error_cb //= sub { warn "@_" };
-
-  unless ( defined $name ) {
-    $error_cb->( 0, "missing argument" );
-    return;
-  }
-
-  my ( $err, @res ) = getaddrinfo( $name, "", { socktype => SOCK_RAW, family => AF_UNSPEC } );
-
-  if ($err) {
-
-    # no error, just no resolveable name
-    return if $err == EAI_NONAME;
-
-    $error_cb->( $err, "getaddrinfo($name)" );
-    return;
-  }
-
-  my @ips;
-
-  while ( my $ai = shift @res ) {
-    my ( $err, $ip ) = getnameinfo( $ai->{addr}, NI_NUMERICHOST, NIx_NOSERV );
-
-    if ($err) {
-      $error_cb->( $err, "getnameinfo($name)" );
-      return;
-    }
-
-    push @ips, $class->new($ip);
-  }
-
-  return @ips;
-}
-
 =head1 FUNCTIONS
 
 L<Net::IPAM::IP> implements the following functions;
